@@ -2,13 +2,14 @@
 # :license: MIT, see LICENSE for more details.
 import click
 
+from SoftLayer.CLI.command import SLCommand as SLCommand
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.managers.account import AccountManager as AccountManager
 from SoftLayer import utils
 
 
-@click.command()
+@click.command(cls=SLCommand, )
 @environment.pass_env
 def cli(env):
     """Displays bandwidth pool information
@@ -20,6 +21,7 @@ def cli(env):
     items = manager.get_bandwidth_pools()
 
     table = formatting.Table([
+        "Id",
         "Pool Name",
         "Region",
         "Servers",
@@ -28,8 +30,8 @@ def cli(env):
         "Projected Usage"
     ], title="Bandwidth Pools")
     table.align = 'l'
-
     for item in items:
+        id_bandwidth = item.get('id')
         name = item.get('name')
         region = utils.lookup(item, 'locationGroup', 'name')
         servers = manager.get_bandwidth_pool_counts(identifier=item.get('id'))
@@ -37,5 +39,5 @@ def cli(env):
         current = "{} GB".format(utils.lookup(item, 'billingCyclePublicBandwidthUsage', 'amountOut'))
         projected = "{} GB".format(item.get('projectedPublicBandwidthUsage', 0))
 
-        table.add_row([name, region, servers, allocation, current, projected])
+        table.add_row([id_bandwidth, name, region, servers, allocation, current, projected])
     env.fout(table)
