@@ -6,29 +6,27 @@ import click
 import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import exceptions
-from SoftLayer.CLI import firewall
 from SoftLayer.CLI import formatting
 
 
 @click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('identifier')
+@click.option('--firewall-type', required=True, show_default=True, default='vlan',
+              type=click.Choice(['vlan', 'server'], case_sensitive=False),
+              help='Firewall type.')
 @environment.pass_env
-def cli(env, identifier):
+def cli(env, identifier, firewall_type):
     """Cancels a firewall."""
 
     mgr = SoftLayer.FirewallManager(env.client)
-    firewall_type, firewall_id = firewall.parse_id(identifier)
 
     if not (env.skip_confirmations or
-            formatting.confirm("This action will cancel a firewall from your "
-                               "account. Continue?")):
+            formatting.confirm("This action will cancel a firewall from your account. Continue?")):
         raise exceptions.CLIAbort('Aborted.')
 
-    if firewall_type in ['vs', 'server']:
-        mgr.cancel_firewall(firewall_id, dedicated=False)
-    elif firewall_type == 'vlan':
-        mgr.cancel_firewall(firewall_id, dedicated=True)
+    if firewall_type == 'server':
+        mgr.cancel_firewall(identifier, dedicated=False)
     else:
-        raise exceptions.CLIAbort('Unknown firewall type: %s' % firewall_type)
+        mgr.cancel_firewall(identifier, dedicated=True)
 
     env.fout('Firewall with id %s is being cancelled!' % identifier)
