@@ -9,24 +9,22 @@ from SoftLayer.CLI import helpers
 from SoftLayer.CLI import ticket
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('identifier')
 @click.option('--body', help="Text to add to the ticket. STDIN or the default text editor will be used otherwise.")
 @environment.pass_env
 def cli(env, identifier, body):
     """Adds an update to an existing ticket.
 
-    Example::
-
-    Will update the ticket with `Some text`.
+Will update the ticket with `Some text`.::
 
         slcli ticket update 123456 --body="Some text"
 
-    Will update the ticket with text from STDIN
+Will update the ticket with text from STDIN::
 
         cat sometfile.txt | slcli ticket update 123456
 
-    Will open the default text editor, and once closed, use that text to update the ticket
+Will open the default text editor, and once closed, use that text to update the ticket::
 
         slcli ticket update 123456
     """
