@@ -18,6 +18,11 @@ class LoadBalancerManager(utils.IdentifierMixin, object):
     :param SoftLayer.API.BaseClient client: the client instance
 
     """
+    TYPE = {
+        1: "Public to Private",
+        0: "Private to Private",
+        2: "Public to Public",
+    }
 
     def __init__(self, client):
         self.client = client
@@ -155,6 +160,33 @@ class LoadBalancerManager(utils.IdentifierMixin, object):
         return self.client.call('SoftLayer_Network_LBaaS_Listener', 'updateLoadBalancerProtocols',
                                 identifier, [listener])
 
+    def get_l7policies(self, identifier):
+        """Gets Layer7 policies from a listener
+
+        :param identifier: id
+        """
+
+        return self.client.call('SoftLayer_Network_LBaaS_Listener', 'getL7Policies', id=identifier)
+
+    def get_all_l7policies(self):
+        """Gets all Layer7 policies
+
+         :returns: Dictionary of (protocol_id: policies list).
+        """
+
+        mask = 'mask[listeners[l7Policies]]'
+        lbaas = self.get_lbaas(mask=mask)
+        listeners = []
+        for load_bal in lbaas:
+            listeners.extend(load_bal.get('listeners'))
+        policies = {}
+        for protocol in listeners:
+            if protocol.get('l7Policies'):
+                listener_id = protocol.get('id')
+                l7policies = protocol.get('l7Policies')
+                policies[listener_id] = l7policies
+        return policies
+
     def add_lb_l7_pool(self, identifier, pool, members, health, session):
         """Creates a new l7 pool for a LBaaS instance
 
@@ -213,7 +245,7 @@ class LoadBalancerManager(utils.IdentifierMixin, object):
             'complexType': 'SoftLayer_Container_Product_Order_Network_LoadBalancer_AsAService',
             'name': name,
             'description': desc,
-            'location': datacenter,
+            'locationObject': datacenter,
             'packageId': package.get('id'),
             'useHourlyPricing': True,  # Required since LBaaS is an hourly service
             'prices': [{'id': price_id} for price_id in prices],
